@@ -42,19 +42,19 @@ my $debug = 0;
 my $man = 0;
 my $help = 0;
 my $pcap = 0;
-my $all = 0;
 my $list_devices = 0;
 my $device;
 my $usbdev = -1;
+my $frame_processor;
 
 GetOptions('debug=i' => \$debug,
 	   'help|?' => \$help,
 	   'pcap' => \$pcap,
-	   'all' => \$all,
 	   'device=s' => \$device,
 	    man => \$man,
 	   'usbdev=i' => \$usbdev,
 	   'list-devices' => \$list_devices,
+	   'frame_processor=s' => \$frame_processor,
 	  ) or pod2usage(2);
 pod2usage(1) if $help;
 pod2usage(-exitstatus => 0, -verbose => 2) if $man;
@@ -180,7 +180,7 @@ sub get_header {
 		 $linktype) = unpack('a4vvVVVV',$header);
 	}
 	else {
-		die "unknown magic in header, cannot parse this file, make sure it is pcap and not a pcapng (run file <filename> to find out) and than convert with wireshark.";
+		die "unknown magic in header, cannot parse this file, make sure it is pcap and not a pcapng (run file <filename> to find out) and then convert with wireshark.";
 	}
 	### Store values
 	$self->{version} = $version;
@@ -345,19 +345,30 @@ sub print_frame($$)
 
 	printf " EP=%02x)", $resp{"Endpoint"};
 
-	my $app_data = substr($req{"Payload"}, 0, 8 * 2);
-	my $type = hex(substr($app_data, 0, 2));
-	while ($app_data ne "") {
-		printf " %s", substr($app_data, 0, 2);
-		$app_data = substr($app_data, 2);
+	my ($app_data, $type);
+
+	if ($req{"Endpoint"} == 0x80 || $req{"SetupFlag"} == 0) {
+		$app_data = substr($req{"Payload"}, 0, 8 * 2);
+		$type = hex(substr($app_data, 0, 2));
+		while ($app_data ne "") {
+			printf " %s", substr($app_data, 0, 2);
+			$app_data = substr($app_data, 2);
+		}
 	}
 
 	# Extra data
-
-	if ($type > 128) {
-		printf " <<<";
+	if ($resp{TransferType} == 2 || $resp{"Endpoint"} != 0x80) {
+		if ($type > 128) {
+			printf " <<<";
+		} else {
+			printf " >>>";
+		}
 	} else {
-		printf " >>>";
+		if ($resp{Endpoint} < 0x80) {
+			print " <<<";
+		} else {
+			print " >>>";
+		}
 	}
 
 	$app_data = substr($req{"Payload"}, 24 * 2);
@@ -403,21 +414,11 @@ sub process_frame($) {
 		print "\n";
 	}
 
-	# For now, we'll take a look only on control frames
-	if ($frame{"TransferType"} ne "2" && $all) {
-		printf "Transfer type: %s\n", $frametype{$frame{"TransferType"}};
-		return;
-	}
-
 	if ($frame{"Status"} eq "-115") {
 		push @pending, \%frame;
 		return;
 	}
 
-# skip unwanted URBs
-	return
-		if $usbdev != -1 and $usbdev != $frame{'Device'};
-
 	# Seek for operation origin
 	my $related = $frame{"ID"};
 	if (!$related) {
@@ -428,7 +429,15 @@ sub process_frame($) {
 		if ($related eq $pending[$i]{"ID"}) {
 			my %req = %{$pending[$i]};
 
-			print_frame (\%req, \%frame);
+# skip unwanted URBs
+			if ($usbdev == -1 or $usbdev == $frame{'Device'}) {
+				if ($frame_processor) {
+					require $frame_processor;
+					frame_processor(\%req, \%frame);
+				} else {
+					print_frame(\%req, \%frame);
+				}
+			}
 
 			# Remove from array, as it were already used
 			splice(@pending, $i, 1);
@@ -476,27 +485,18 @@ sub decode_frame($) {
 		print "\n";
 	}
 
-	my ($frame_id, $setuprequest, $hasdata, $tsSecHigh, $tsSecLow, $tsUsec);
+	my ($frame_id, $tsSecHigh, $tsSecLow, $tsUsec);
 
 	($frame_id, $frame{"Type"}, $frame{"TransferType"},
 		$frame{"Endpoint"}, $frame{"Device"}, $frame{"BusID"},
-		$setuprequest, $hasdata, $tsSecHigh, $tsSecLow, $tsUsec,
+		$frame{"SetupFlag"}, $frame{"DataFlag"},
+		$tsSecHigh, $tsSecLow, $tsUsec,
 		$frame{"Status"}, $frame{"URBLength"},
 		$frame{"DataLength"}) = unpack("A8CCCCvCCVVVlVV", $strdata);
 	$frame{"ID"} = "0x";
 	for (my $i = 7; $i >= 0; $i--) {
 		$frame{"ID"} .= sprintf "%02x", ord(substr($frame_id, $i, 1));
 	}
-	if ($setuprequest == 0) {
-		$frame{"SetupRequest"} = "present";
-	} else {
-		$frame{"SetupRequest"} = "not present";
-	}
-	if ($hasdata == 0) {
-		$frame{"HasData"} = "present";
-	} else {
-		$frame{"HasData"} = "not present";
-	}
 	$frame{"Type"} = chr($frame{"Type"});
 	$frame{"ArrivalTime"} = sprintf "%d.%06d", $tsSecHigh << 32 | $tsSecLow, $tsUsec;
 
@@ -648,6 +648,8 @@ Options:
 
 	--list-devices          list the available USB devices for each usbmon port
 
+	--frame_processor [file] have this script call the function frame_processor of the script in file instead of printing.
+
 =head1 OPTIONS
 
 =over 8
@@ -692,6 +694,14 @@ Lists all connected USB devices, and the associated usbmon device.
 Filter traffic with given usbdev-id. By default no filtering is done
 and usbdev is -1.
 
+=item B<--frame_processor [perl-script]>
+
+Provide this option with a filename to a perl-script which contains a function
+frame_processor and instead of having the USB-frames printed to the screen
+you can process them programmatically. See print_frame for an example. This
+option exists to avoid the reparsing of the output generated by this script
+for analyzing.
+
 =back
 
 =head1 DESCRIPTION
