@@ -20,13 +20,63 @@
 
 #include "dvb-fe-priv.h"
 #include "dvb-v5.h"
+#include <libdvbv5/countries.h>
 #include <libdvbv5/dvb-v5-std.h>
 
 #include <inttypes.h>
 #include <math.h>
 #include <stddef.h>
+#include <time.h>
 #include <unistd.h>
 
+#include <config.h>
+
+#ifdef ENABLE_NLS
+# include "gettext.h"
+# include <libintl.h>
+# define _(string) dgettext(LIBDVBV5_DOMAIN, string)
+
+static int libdvbv5_initialized = 0;
+
+#else
+# define _(string) string
+#endif
+
+# define N_(string) string
+
+#define MAX_TIME		10	/* 1.0 seconds */
+
+#define xioctl(fh, request, arg...) ({					\
+	int __rc;							\
+	struct timespec __start, __end;					\
+									\
+	clock_gettime(CLOCK_MONOTONIC, &__start);			\
+	do {								\
+		__rc = ioctl(fh, request, ##arg);			\
+		if (__rc != -1)						\
+			break;						\
+		if ((errno != EINTR) && (errno != EAGAIN))		\
+			break;						\
+		clock_gettime(CLOCK_MONOTONIC, &__end);			\
+		if (__end.tv_sec * 10 + __end.tv_nsec / 100000000 >	\
+		    __start.tv_sec * 10 + __start.tv_nsec / 100000000 +	\
+		    MAX_TIME)						\
+			break;						\
+	} while (1);							\
+									\
+	__rc;								\
+})
+
+static void libdvbv5_initialize(void)
+{
+#ifdef ENABLE_NLS
+	if (libdvbv5_initialized)
+		return;
+	bindtextdomain(LIBDVBV5_DOMAIN, LOCALEDIR);
+	libdvbv5_initialized = 1;
+#endif
+}
+
 static void dvb_v5_free(struct dvb_v5_fe_parms_priv *parms)
 {
 	if (parms->fname)
@@ -39,6 +89,8 @@ struct dvb_v5_fe_parms *dvb_fe_dummy()
 {
 	struct dvb_v5_fe_parms_priv *parms = NULL;
 
+	libdvbv5_initialize();
+
 	parms = calloc(sizeof(*parms), 1);
 	if (!parms)
 		return NULL;
@@ -77,28 +129,30 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 	struct dtv_properties dtv_prop;
 	struct dvb_v5_fe_parms_priv *parms = NULL;
 
+	libdvbv5_initialize();
+
 	if (logfunc == NULL)
 		logfunc = dvb_default_log;
 
 	r = asprintf(&fname, "/dev/dvb/adapter%i/frontend%i", adapter, frontend);
 	if (r < 0) {
-		logfunc(LOG_ERR, "asprintf error");
+		logfunc(LOG_ERR, _("asprintf error"));
 		return NULL;
 	}
 	if (!fname) {
-		logfunc(LOG_ERR, "fname calloc: %s", strerror(errno));
+		logfunc(LOG_ERR, _("fname calloc: %s"), strerror(errno));
 		return NULL;
 	}
 
 	fd = open(fname, flags, 0);
 	if (fd == -1) {
-		logfunc(LOG_ERR, "%s while opening %s", strerror(errno), fname);
+		logfunc(LOG_ERR, _("%s while opening %s"), strerror(errno), fname);
 		free(fname);
 		return NULL;
 	}
 	parms = calloc(sizeof(*parms), 1);
 	if (!parms) {
-		logfunc(LOG_ERR, "parms calloc: %s", strerror(errno));
+		logfunc(LOG_ERR, _("parms calloc: %s"), strerror(errno));
 		close(fd);
 		free(fname);
 		return NULL;
@@ -113,8 +167,9 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 	parms->p.lna = LNA_AUTO;
 	parms->p.sat_number = -1;
 	parms->p.abort = 0;
+	parms->country = COUNTRY_UNKNOWN;
 
-	if (ioctl(fd, FE_GET_INFO, &parms->p.info) == -1) {
+	if (xioctl(fd, FE_GET_INFO, &parms->p.info) == -1) {
 		dvb_perror("FE_GET_INFO");
 		dvb_v5_free(parms);
 		close(fd);
@@ -125,7 +180,7 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 	if (verbose) {
 		fe_caps_t caps = parms->p.info.caps;
 
-		dvb_log("Device %s (%s) capabilities:",
+		dvb_log(_("Device %s (%s) capabilities:"),
 			parms->p.info.name, fname);
 		for (i = 0; i < ARRAY_SIZE(fe_caps_name); i++) {
 			if (caps & fe_caps_name[i].idx)
@@ -140,17 +195,18 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 	dtv_prop.props = parms->dvb_prop;
 
 	/* Detect a DVBv3 device */
-	if (ioctl(fd, FE_GET_PROPERTY, &dtv_prop) == -1) {
+	if (xioctl(fd, FE_GET_PROPERTY, &dtv_prop) == -1) {
 		parms->dvb_prop[0].u.data = 0x300;
 		parms->dvb_prop[1].u.data = SYS_UNDEFINED;
 	}
+
 	parms->p.version = parms->dvb_prop[0].u.data;
 	parms->p.current_sys = parms->dvb_prop[1].u.data;
 	if (verbose)
-		dvb_log ("DVB API Version %d.%d%s, Current v5 delivery system: %s",
+		dvb_log (_("DVB API Version %d.%d%s, Current v5 delivery system: %s"),
 			parms->p.version / 256,
 			parms->p.version % 256,
-			use_legacy_call ? " (forcing DVBv3 calls)" : "",
+			use_legacy_call ? _(" (forcing DVBv3 calls)") : "",
 			delivery_system_name[parms->p.current_sys]);
 
 	if (parms->p.version < 0x500)
@@ -195,7 +251,7 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 			break;
 		}
 		if (!parms->p.num_systems) {
-			dvb_logerr("delivery system not detected");
+			dvb_logerr(_("delivery system not detected"));
 			dvb_v5_free(parms);
 			close(fd);
 			return NULL;
@@ -205,7 +261,7 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 		parms->n_props = 1;
 		dtv_prop.num = 1;
 		dtv_prop.props = parms->dvb_prop;
-		if (ioctl(fd, FE_GET_PROPERTY, &dtv_prop) == -1) {
+		if (xioctl(fd, FE_GET_PROPERTY, &dtv_prop) == -1) {
 			dvb_perror("FE_GET_PROPERTY");
 			dvb_v5_free(parms);
 			close(fd);
@@ -216,7 +272,7 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 			parms->p.systems[i] = parms->dvb_prop[0].u.buffer.data[i];
 
 		if (parms->p.num_systems == 0) {
-			dvb_logerr("driver returned 0 supported delivery systems!");
+			dvb_logerr(_("driver returned 0 supported delivery systems!"));
 			dvb_v5_free(parms);
 			close(fd);
 			return NULL;
@@ -224,7 +280,7 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 	}
 
 	if (verbose) {
-		dvb_log("Supported delivery system%s: ",
+		dvb_log(_("Supported delivery system%s: "),
 		       (parms->p.num_systems > 1) ? "s" : "");
 		for (i = 0; i < parms->p.num_systems; i++) {
 			if (parms->p.systems[i] == parms->p.current_sys)
@@ -235,7 +291,7 @@ struct dvb_v5_fe_parms *dvb_fe_open_flags(int adapter, int frontend,
 					delivery_system_name[parms->p.systems[i]]);
 		}
 		if (use_legacy_call || parms->p.version < 0x505)
-			dvb_log("Warning: new delivery systems like ISDB-T, ISDB-S, DMB-TH, DSS, ATSC-MH will be miss-detected by a DVBv5.4 or earlier API call");
+			dvb_log(_("Warning: new delivery systems like ISDB-T, ISDB-S, DMB-TH, DSS, ATSC-MH will be miss-detected by a DVBv5.4 or earlier API call"));
 	}
 
 	/*
@@ -359,8 +415,8 @@ int dvb_set_sys(struct dvb_v5_fe_parms *p, fe_delivery_system_t sys)
 		prop.num = 1;
 		prop.props = dvb_prop;
 
-		if (ioctl(parms->fd, FE_SET_PROPERTY, &prop) == -1) {
-			dvb_perror("Set delivery system");
+		if (xioctl(parms->fd, FE_SET_PROPERTY, &prop) == -1) {
+			dvb_perror(_("Set delivery system"));
 			return errno;
 		}
 	}
@@ -390,7 +446,7 @@ static enum dvbv3_emulation_type dvbv3_type(uint32_t delivery_system)
 	case SYS_DVBT:
 	case SYS_DVBT2:
 	case SYS_ISDBT:
-	case SYS_DMBTH:
+	case SYS_DTMB:
 		return DVBV3_OFDM;
 	case SYS_ATSC:
 	case SYS_ATSCMH:
@@ -446,7 +502,7 @@ int dvb_set_compat_delivery_system(struct dvb_v5_fe_parms *p,
 	if (delsys == SYS_UNDEFINED)
 		return EINVAL;
 
-	dvb_log("Using a DVBv3 compat file for %s", delivery_system_name[delsys]);
+	dvb_log(_("Using a DVBv3 compat file for %s"), delivery_system_name[delsys]);
 
 	dvb_set_sys(&parms->p, delsys);
 
@@ -535,7 +591,7 @@ int dvb_fe_retrieve_parm(const struct dvb_v5_fe_parms *p,
 		*value = parms->dvb_prop[i].u.data;
 		return 0;
 	}
-	dvb_logerr("command %s (%d) not found during retrieve",
+	dvb_logerr(_("command %s (%d) not found during retrieve"),
 		dvb_cmd_name(cmd), cmd);
 
 	return EINVAL;
@@ -552,7 +608,7 @@ int dvb_fe_store_parm(struct dvb_v5_fe_parms *p,
 		parms->dvb_prop[i].u.data = value;
 		return 0;
 	}
-	dvb_logerr("command %s (%d) not found during store",
+	dvb_logerr(_("command %s (%d) not found during store"),
 		dvb_cmd_name(cmd), cmd);
 
 	return EINVAL;
@@ -598,24 +654,28 @@ int dvb_fe_get_parms(struct dvb_v5_fe_parms *p)
 	prop.props = fe_prop;
 	prop.num = n;
 	if (!parms->p.legacy_fe) {
-		if (ioctl(parms->fd, FE_GET_PROPERTY, &prop) == -1) {
+		if (xioctl(parms->fd, FE_GET_PROPERTY, &prop) == -1) {
 			dvb_perror("FE_GET_PROPERTY");
 			return errno;
 		}
 
 		/* copy back params from temporary fe_prop */
-		for (i = 0; i < n; i++)
+		for (i = 0; i < n; i++) {
+			if (dvb_fe_is_satellite(p->current_sys)
+			    && fe_prop[i].cmd == DTV_FREQUENCY)
+				fe_prop[i].u.data += parms->freq_offset;
 			dvb_fe_store_parm(&parms->p, fe_prop[i].cmd, fe_prop[i].u.data);
+		}
 
 		if (parms->p.verbose) {
-			dvb_log("Got parameters for %s:",
+			dvb_log(_("Got parameters for %s:"),
 			       delivery_system_name[parms->p.current_sys]);
 			dvb_fe_prt_parms(&parms->p);
 		}
 		return 0;
 	}
 	/* DVBv3 call */
-	if (ioctl(parms->fd, FE_GET_FRONTEND, &v3_parms) == -1) {
+	if (xioctl(parms->fd, FE_GET_FRONTEND, &v3_parms) == -1) {
 		dvb_perror("FE_GET_FRONTEND");
 		return EINVAL;
 	}
@@ -656,6 +716,56 @@ int dvb_fe_get_parms(struct dvb_v5_fe_parms *p)
 	return 0;
 }
 
+/* set the delsys default/fixed parameters and replace DVBv5 default values */
+static void dvb_setup_delsys_default(struct dvb_v5_fe_parms *p)
+{
+	struct dvb_v5_fe_parms_priv *parms = (void *)p;
+	uint32_t cc;
+
+	switch (p->current_sys) {
+	case SYS_ISDBT:
+		/* Set country code. */
+		/* if the default country is not known, fallback to BR */
+		cc = COUNTRY_UNKNOWN;
+		dvb_fe_retrieve_parm(p, DTV_COUNTRY_CODE, &cc);
+		if (cc == COUNTRY_UNKNOWN) {
+			cc = (parms->country == COUNTRY_UNKNOWN)
+				? BR : parms->country;
+			dvb_fe_store_parm(p, DTV_COUNTRY_CODE, cc);
+		}
+		switch (cc) {
+		case JP:
+			p->default_charset = "arib-std-b24";
+			dvb_fe_store_parm(p, DTV_BANDWIDTH_HZ, 6000000);
+			break;
+		/* Americas (SBTVD) */
+		case AR:
+		case BO:
+		case BR:
+		case CL:
+		case CR:
+		case EC:
+		case GT:
+		case HN:
+		case NI:
+		case PE:
+		case PY:
+		case UY:
+		case VE:
+			p->default_charset = "iso8859-15";
+			break;
+		}
+		break;
+	case SYS_ISDBS:
+		p->default_charset = "arib-std-b24";
+		if (!p->lnb)
+			p->lnb = dvb_sat_get_lnb(dvb_sat_search_lnb("110BS"));
+		break;
+	default:
+		break;
+	}
+}
+
 int dvb_fe_set_parms(struct dvb_v5_fe_parms *p)
 {
 	struct dvb_v5_fe_parms_priv *parms = (void *)p;
@@ -676,15 +786,28 @@ int dvb_fe_set_parms(struct dvb_v5_fe_parms *p)
 		prop.props[0].cmd = DTV_LNA;
 		prop.props[0].u.data = parms->p.lna;
 		prop.num = 1;
-		if (ioctl(parms->fd, FE_SET_PROPERTY, &prop) == -1) {
-			dvb_perror("Setting LNA");
+		if (xioctl(parms->fd, FE_SET_PROPERTY, &prop) == -1) {
+			dvb_perror(_("Setting LNA"));
 			parms->p.lna = LNA_AUTO;
 		} else if (parms->p.lna != LNA_AUTO && parms->p.verbose)
-			dvb_logdbg("LNA is %s", parms->p.lna ? "ON" : "OFF");
+			dvb_logdbg(_("LNA is %s"), parms->p.lna ? _("ON") : _("OFF"));
 	}
 
-	if (dvb_fe_is_satellite(tmp_parms.p.current_sys))
+	if (dvb_fe_is_satellite(tmp_parms.p.current_sys)) {
 		dvb_sat_set_parms(&tmp_parms.p);
+		/*
+		 * even though the frequncy prop is kept un-modified here,
+		 * a later call to dvb_fe_get_parms() issues FE_GET_PROPERTY
+		 * ioctl and overwrites it with the offset-ed value from
+		 * the FE. So we need to save the offset here and
+		 * re-add it in dvb_fe_get_parms().
+		 * note that dvbv5-{scan,zap} utilities call dvb_fe_get_parms()
+		 * indirectly from check_frontend() via dvb_fe_get_stats().
+		 */
+		parms->freq_offset = tmp_parms.freq_offset;
+	}
+
+	dvb_setup_delsys_default(p);
 
 	/* Filter out any user DTV_foo property such as DTV_POLARIZATION */
 	tmp_parms.n_props = dvb_copy_fe_props(tmp_parms.dvb_prop,
@@ -698,7 +821,7 @@ int dvb_fe_set_parms(struct dvb_v5_fe_parms *p)
 	prop.num++;
 
 	if (!parms->p.legacy_fe) {
-		if (ioctl(parms->fd, FE_SET_PROPERTY, &prop) == -1) {
+		if (xioctl(parms->fd, FE_SET_PROPERTY, &prop) == -1) {
 			dvb_perror("FE_SET_PROPERTY");
 			if (parms->p.verbose)
 				dvb_fe_prt_parms(&parms->p);
@@ -707,7 +830,6 @@ int dvb_fe_set_parms(struct dvb_v5_fe_parms *p)
 		return 0;
 	}
 	/* DVBv3 call */
-
 	dvb_fe_retrieve_parm(&tmp_parms.p, DTV_FREQUENCY, &v3_parms.frequency);
 	dvb_fe_retrieve_parm(&tmp_parms.p, DTV_INVERSION, &v3_parms.inversion);
 	switch (tmp_parms.p.current_sys) {
@@ -739,13 +861,13 @@ int dvb_fe_set_parms(struct dvb_v5_fe_parms *p)
 		dvb_fe_retrieve_parm(&tmp_parms.p, DTV_HIERARCHY, &v3_parms.u.ofdm.hierarchy_information);
 		break;
 	default:
-		return EINVAL;
+		return -1;
 	}
-	if (ioctl(tmp_parms.fd, FE_SET_FRONTEND, &v3_parms) == -1) {
+	if (xioctl(tmp_parms.fd, FE_SET_FRONTEND, &v3_parms) == -1) {
 		dvb_perror("FE_SET_FRONTEND");
 		if (tmp_parms.p.verbose)
 			dvb_fe_prt_parms(&tmp_parms.p);
-		return EINVAL;
+		return -1;
 	}
 
 	return 0;
@@ -768,7 +890,7 @@ static struct dtv_stats *dvb_fe_store_stats(struct dvb_v5_fe_parms_priv *parms,
 			parms->stats.prop[i].u.st.len = layer + 1;
 		return &parms->stats.prop[i].u.st.stat[layer];
 	}
-	dvb_logerr("%s not found on store", dvb_cmd_name(cmd));
+	dvb_logerr(_("%s not found on store"), dvb_cmd_name(cmd));
 
 	return NULL;
 }
@@ -840,7 +962,7 @@ struct dtv_stats *dvb_fe_retrieve_stats_layer(struct dvb_v5_fe_parms *p,
 			return NULL;
 		return &parms->stats.prop[i].u.st.stat[layer];
 	}
-	dvb_logerr("%s not found on retrieve", dvb_cmd_name(cmd));
+	dvb_logerr(_("%s not found on retrieve"), dvb_cmd_name(cmd));
 
 	return NULL;
 }
@@ -855,21 +977,21 @@ int dvb_fe_retrieve_stats(struct dvb_v5_fe_parms *p,
 	stat = dvb_fe_retrieve_stats_layer(&parms->p, cmd, 0);
 	if (!stat) {
 		if (parms->p.verbose)
-			dvb_logdbg("%s not found on retrieve", dvb_cmd_name(cmd));
+			dvb_logdbg(_("%s not found on retrieve"), dvb_cmd_name(cmd));
 		return EINVAL;
 	}
 
 	scale = stat->scale;
 	if (scale == FE_SCALE_NOT_AVAILABLE) {
 		if (parms->p.verbose)
-			dvb_logdbg("%s not available", dvb_cmd_name(cmd));
+			dvb_logdbg(_("%s not available"), dvb_cmd_name(cmd));
 		return EINVAL;
 	}
 
 	*value = stat->uvalue;
 
 	if (parms->p.verbose > 1)
-		dvb_logdbg("Stats for %s = %d", dvb_cmd_name(cmd), *value);
+		dvb_logdbg(_("Stats for %s = %d"), dvb_cmd_name(cmd), *value);
 
 	return 0;
 }
@@ -1103,7 +1225,7 @@ static enum dvb_quality dvbv_fe_cnr_to_quality(struct dvb_v5_fe_parms_priv *parm
 	case SYS_TURBO:
 	case SYS_ISDBS:
 	case SYS_DSS:
-	case SYS_DMBTH:
+	case SYS_DTMB:
 	case SYS_ATSC:
 	case SYS_ATSCMH:
 	case SYS_DVBC_ANNEX_B:
@@ -1217,7 +1339,7 @@ int dvb_fe_get_stats(struct dvb_v5_fe_parms *p)
 	int i;
 	enum fecap_scale_params scale;
 
-	if (ioctl(parms->fd, FE_READ_STATUS, &status) == -1) {
+	if (xioctl(parms->fd, FE_READ_STATUS, &status) == -1) {
 		dvb_perror("FE_READ_STATUS");
 		return EINVAL;
 	}
@@ -1238,8 +1360,11 @@ int dvb_fe_get_stats(struct dvb_v5_fe_parms *p)
 		props.props = parms->stats.prop;
 
 		/* Do a DVBv5.10 stats call */
-		if (ioctl(parms->fd, FE_GET_PROPERTY, &props) == -1)
+		if (ioctl(parms->fd, FE_GET_PROPERTY, &props) == -1) {
+			if (errno == EAGAIN)
+				return 0;
 			goto dvbv3_fallback;
+		}
 
 		/*
 		 * All props with len=0 mean that this device doesn't have any
@@ -1291,12 +1416,12 @@ dvbv3_fallback:
 	dvb_fe_store_stats(parms, DTV_STAT_ERROR_BLOCK_COUNT, scale, 0, snr);
 
 	if (parms->p.verbose > 1) {
-		dvb_log("Status: ");
+		dvb_log(_("Status: "));
 		for (i = 0; i < ARRAY_SIZE(fe_status_name); i++) {
 			if (status & fe_status_name[i].idx)
 				dvb_log ("    %s", fe_status_name[i].name);
 		}
-		dvb_log("BER: %d, Strength: %d, SNR: %d, UCB: %d",
+		dvb_log(_("BER: %d, Strength: %d, SNR: %d, UCB: %d"),
 		       ber, strength, snr, ucb);
 	}
 	return 0;
@@ -1315,13 +1440,13 @@ int dvb_fe_get_event(struct dvb_v5_fe_parms *p)
 		return dvb_fe_get_stats(&parms->p);
 	}
 
-	if (ioctl(parms->fd, FE_GET_EVENT, &event) == -1) {
+	if (xioctl(parms->fd, FE_GET_EVENT, &event) == -1) {
 		dvb_perror("FE_GET_EVENT");
 		return errno;
 	}
 	status = event.status;
 	if (parms->p.verbose > 1) {
-		dvb_log("Status: ");
+		dvb_log(_("Status: "));
 		for (i = 0; i < ARRAY_SIZE(fe_status_name); i++) {
 			if (status & fe_status_name[i].idx)
 				dvb_log ("    %s", fe_status_name[i].name);
@@ -1413,19 +1538,19 @@ int dvb_fe_snprintf_eng(char *buf, int len, float val)
 }
 
 static char *sig_bits[7] = {
-	[0] = "RF",
-	[1] = "Carrier",
-	[2] = "Viterbi",
-	[3] = "Sync",
-	[4] = "Lock",
-	[5] = "Timeout",
-	[6] = "Reinit",
+	[0] = N_("RF"),
+	[1] = N_("Carrier"),
+	[2] = N_("Viterbi"),
+	[3] = N_("Sync"),
+	[4] = N_("Lock"),
+	[5] = N_("Timeout"),
+	[6] = N_("Reinit"),
 };
 
 static char *qual_name[] = {
-	[DVB_QUAL_POOR] = "Poor",
-	[DVB_QUAL_OK]   = "Ok",
-	[DVB_QUAL_GOOD] = "Good",
+	[DVB_QUAL_POOR] = N_("Poor"),
+	[DVB_QUAL_OK]   = N_("Ok"),
+	[DVB_QUAL_GOOD] = N_("Good"),
 };
 
 int dvb_fe_snprintf_stat(struct dvb_v5_fe_parms *p, uint32_t cmd,
@@ -1448,7 +1573,7 @@ int dvb_fe_snprintf_stat(struct dvb_v5_fe_parms *p, uint32_t cmd,
 			return 0;
 
 		if (dvb_fe_retrieve_stats(&parms->p, DTV_STATUS, &status)) {
-			dvb_logerr ("Error: no adapter status");
+			dvb_logerr (_("Error: no adapter status"));
 			return -1;
 		}
 		if (display_name) {
@@ -1460,14 +1585,14 @@ int dvb_fe_snprintf_stat(struct dvb_v5_fe_parms *p, uint32_t cmd,
 		/* Get the name of the highest status bit */
 		for (i = ARRAY_SIZE(sig_bits) - 1; i >= 0 ; i--) {
 			if ((1 << i) & status) {
-				size = snprintf(*buf, *len, "%-7s", sig_bits[i]);
+				size = snprintf(*buf, *len, _("%-7s"), _(sig_bits[i]));
 				*buf += size;
 				*len -= size;
 				break;
 			}
 		}
 		if (i < 0) {
-			size = snprintf(*buf, *len, "%7s", "");
+			size = snprintf(*buf, *len, _("%7s"), "");
 			*buf += size;
 			*len -= size;
 		}
@@ -1512,7 +1637,7 @@ int dvb_fe_snprintf_stat(struct dvb_v5_fe_parms *p, uint32_t cmd,
 
 	/* If requested, prints the layer name */
 	if (*show_layer_name && layer) {
-		size = snprintf(*buf, *len, "  Layer %c:", 'A' + layer - 1);
+		size = snprintf(*buf, *len, _("  Layer %c:"), 'A' + layer - 1);
 		*buf += size;
 		*len -= size;
 		*show_layer_name = 0;
@@ -1525,7 +1650,7 @@ int dvb_fe_snprintf_stat(struct dvb_v5_fe_parms *p, uint32_t cmd,
 
 	/* Quality measure */
 	if (qual != DVB_QUAL_UNKNOWN) {
-		size = snprintf(*buf, *len, " %-4s", qual_name[qual]);
+		size = snprintf(*buf, *len, " %-4s", _(qual_name[qual]));
 		*buf += size;
 		*len -= size;
 		return initial_len - *len;
@@ -1587,13 +1712,13 @@ int dvb_fe_sec_voltage(struct dvb_v5_fe_parms *p, int on, int v18)
 	if (!on) {
 		v = SEC_VOLTAGE_OFF;
 		if (parms->p.verbose)
-			dvb_log("DiSEqC VOLTAGE: OFF");
+			dvb_log(_("DiSEqC VOLTAGE: OFF"));
 	} else {
 		v = v18 ? SEC_VOLTAGE_18 : SEC_VOLTAGE_13;
 		if (parms->p.verbose)
-			dvb_log("DiSEqC VOLTAGE: %s", v18 ? "18" : "13");
+			dvb_log(_("DiSEqC VOLTAGE: %s"), v18 ? "18" : "13");
 	}
-	rc = ioctl(parms->fd, FE_SET_VOLTAGE, v);
+	rc = xioctl(parms->fd, FE_SET_VOLTAGE, v);
 	if (rc == -1)
 		dvb_perror("FE_SET_VOLTAGE");
 	return rc;
@@ -1604,8 +1729,8 @@ int dvb_fe_sec_tone(struct dvb_v5_fe_parms *p, fe_sec_tone_mode_t tone)
 	struct dvb_v5_fe_parms_priv *parms = (void *)p;
 	int rc;
 	if (parms->p.verbose)
-		dvb_log( "DiSEqC TONE: %s", fe_tone_name[tone] );
-	rc = ioctl(parms->fd, FE_SET_TONE, tone);
+		dvb_log( _("DiSEqC TONE: %s"), fe_tone_name[tone] );
+	rc = xioctl(parms->fd, FE_SET_TONE, tone);
 	if (rc == -1)
 		dvb_perror("FE_SET_TONE");
 	return rc;
@@ -1618,8 +1743,8 @@ int dvb_fe_lnb_high_voltage(struct dvb_v5_fe_parms *p, int on)
 
 	if (on) on = 1;
 	if (parms->p.verbose)
-		dvb_log( "DiSEqC HIGH LNB VOLTAGE: %s", on ? "ON" : "OFF" );
-	rc = ioctl(parms->fd, FE_ENABLE_HIGH_LNB_VOLTAGE, on);
+		dvb_log( _("DiSEqC HIGH LNB VOLTAGE: %s"), on ? _("ON") : _("OFF") );
+	rc = xioctl(parms->fd, FE_ENABLE_HIGH_LNB_VOLTAGE, on);
 	if (rc == -1)
 		dvb_perror("FE_ENABLE_HIGH_LNB_VOLTAGE");
 	return rc;
@@ -1634,8 +1759,8 @@ int dvb_fe_diseqc_burst(struct dvb_v5_fe_parms *p, int mini_b)
 	mini = mini_b ? SEC_MINI_B : SEC_MINI_A;
 
 	if (parms->p.verbose)
-		dvb_log( "DiSEqC BURST: %s", mini_b ? "SEC_MINI_B" : "SEC_MINI_A" );
-	rc = ioctl(parms->fd, FE_DISEQC_SEND_BURST, mini);
+		dvb_log( _("DiSEqC BURST: %s"), mini_b ? "SEC_MINI_B" : "SEC_MINI_A" );
+	rc = xioctl(parms->fd, FE_DISEQC_SEND_BURST, mini);
 	if (rc == -1)
 		dvb_perror("FE_DISEQC_SEND_BURST");
 	return rc;
@@ -1658,13 +1783,13 @@ int dvb_fe_diseqc_cmd(struct dvb_v5_fe_parms *p, const unsigned len,
 		int i;
 		char log[len * 3 + 20], *p = log;
 
-		p += sprintf(p, "DiSEqC command: ");
+		p += sprintf(p, _("DiSEqC command: "));
 		for (i = 0; i < len; i++)
 			p += sprintf (p, "%02x ", buf[i]);
 		dvb_log("%s", log);
 	}
 
-	rc = ioctl(parms->fd, FE_DISEQC_SEND_MASTER_CMD, &msg);
+	rc = xioctl(parms->fd, FE_DISEQC_SEND_MASTER_CMD, &msg);
 	if (rc == -1)
 		dvb_perror("FE_DISEQC_SEND_MASTER_CMD");
 	return rc;
@@ -1686,7 +1811,7 @@ int dvb_fe_diseqc_reply(struct dvb_v5_fe_parms *p, unsigned *len, char *buf,
 	if (parms->p.verbose)
 		dvb_log("DiSEqC FE_DISEQC_RECV_SLAVE_REPLY");
 
-	rc = ioctl(parms->fd, FE_DISEQC_RECV_SLAVE_REPLY, reply);
+	rc = xioctl(parms->fd, FE_DISEQC_RECV_SLAVE_REPLY, reply);
 	if (rc == -1) {
 		dvb_perror("FE_DISEQC_RECV_SLAVE_REPLY");
 		return rc;
@@ -1697,3 +1822,23 @@ int dvb_fe_diseqc_reply(struct dvb_v5_fe_parms *p, unsigned *len, char *buf,
 
 	return 0;
 }
+
+int dvb_fe_set_default_country(struct dvb_v5_fe_parms *p, const char *cc)
+{
+	struct dvb_v5_fe_parms_priv *parms = (void *)p;
+
+	if (!cc) {
+		parms->country = dvb_guess_user_country();
+		if (parms->p.verbose) {
+			if (parms->country != COUNTRY_UNKNOWN)
+				dvb_log(_("Assuming you're in %s.\n"),
+					dvb_country_to_2letters(parms->country));
+			else
+				dvb_log(_("Failed to guess country from the current locale setting.\n"));
+		}
+		return 0;
+	}
+
+	parms->country = dvb_country_a2_to_id(cc);
+	return (parms->country == COUNTRY_UNKNOWN) ? -EINVAL : 0;
+}
