@@ -48,6 +48,20 @@
 #include <libdvbv5/desc_event_extended.h>
 #include <libdvbv5/desc_atsc_service_location.h>
 #include <libdvbv5/desc_hierarchy.h>
+#include <libdvbv5/countries.h>
+
+#include <config.h>
+
+#ifdef ENABLE_NLS
+# include "gettext.h"
+# include <libintl.h>
+# define _(string) dgettext(LIBDVBV5_DOMAIN, string)
+
+#else
+# define _(string) string
+#endif
+
+# define N_(string) string
 
 int dvb_store_entry_prop(struct dvb_entry *entry,
 			 uint32_t cmd, uint32_t value)
@@ -60,7 +74,7 @@ int dvb_store_entry_prop(struct dvb_entry *entry,
 	}
 	if (i == entry->n_props) {
 		if (i == DTV_MAX_COMMAND) {
-			fprintf(stderr, "Can't add property %s\n",
+			fprintf(stderr, _("Can't add property %s\n"),
 			       dvb_v5_name[cmd]);
 			return -1;
 		}
@@ -149,6 +163,9 @@ static uint32_t dvbv5_default_value(int cmd)
 		case DTV_ROLLOFF:
 			return ROLLOFF_AUTO;
 
+		case DTV_COUNTRY_CODE:
+			return COUNTRY_UNKNOWN;
+
 		default:
 			return (uint32_t)-1;
 	}
@@ -221,7 +238,7 @@ struct dvb_file *dvb_parse_format_oneline(const char *fname,
 
 	dvb_file = calloc(sizeof(*dvb_file), 1);
 	if (!dvb_file) {
-		perror("Allocating memory for dvb_file");
+		perror(_("Allocating memory for dvb_file"));
 		return NULL;
 	}
 
@@ -247,7 +264,7 @@ struct dvb_file *dvb_parse_format_oneline(const char *fname,
 		if (parse_file->has_delsys_id) {
 			p = strtok(p, delimiter);
 			if (!p) {
-				sprintf(err_msg, "unknown delivery system type for %s",
+				sprintf(err_msg, _("unknown delivery system type for %s"),
 					p);
 				goto error;
 			}
@@ -258,7 +275,7 @@ struct dvb_file *dvb_parse_format_oneline(const char *fname,
 					break;
 			}
 			if (!formats[i].id) {
-				sprintf(err_msg, "Doesn't know how to handle delimiter '%s'",
+				sprintf(err_msg, _("Doesn't know how to handle delimiter '%s'"),
 					p);
 				goto error;
 			}
@@ -269,7 +286,7 @@ struct dvb_file *dvb_parse_format_oneline(const char *fname,
 					break;
 			}
 			if (!formats[i].delsys) {
-				sprintf(err_msg, "Doesn't know how to parse delivery system %d",
+				sprintf(err_msg, _("Doesn't know how to parse delivery system %d"),
 					delsys);
 				goto error;
 			}
@@ -297,7 +314,7 @@ struct dvb_file *dvb_parse_format_oneline(const char *fname,
 			if (p && *p == '#')
 				p = NULL;
 			if (!p && !fmt->table[i].has_default_value) {
-				sprintf(err_msg, "parameter %i (%s) missing",
+				sprintf(err_msg, _("parameter %i (%s) missing"),
 					i, dvb_cmd_name(table->prop));
 				goto error;
 			}
@@ -306,7 +323,7 @@ struct dvb_file *dvb_parse_format_oneline(const char *fname,
 					if (!table->table[j] || !strcasecmp(table->table[j], p))
 						break;
 				if (j == table->size) {
-					sprintf(err_msg, "parameter %s invalid: %s",
+					sprintf(err_msg, _("parameter %s invalid: %s"),
 						dvb_cmd_name(table->prop), p);
 					goto error;
 				}
@@ -363,7 +380,7 @@ struct dvb_file *dvb_parse_format_oneline(const char *fname,
 	return dvb_file;
 
 error:
-	fprintf (stderr, "ERROR %s while parsing line %d of %s\n",
+	fprintf (stderr, _("ERROR %s while parsing line %d of %s\n"),
 		 err_msg, line, fname);
 	dvb_file_free(dvb_file);
 	fclose(fd);
@@ -391,6 +408,7 @@ static uint32_t get_compat_format(uint32_t delivery_system)
 	case SYS_ISDBT:
 	case SYS_DVBT:
 	case SYS_DVBT2:
+	case SYS_DTMB:
 		return SYS_DVBT;
 	default:
 		return 0;
@@ -443,7 +461,7 @@ int dvb_write_format_oneline(const char *fname,
 		}
 		if (formats[i].delsys == 0) {
 			sprintf(err_msg,
-				 "delivery system %d not supported on this format",
+				 _("delivery system %d not supported on this format"),
 				 delsys);
 			goto error;
 		}
@@ -485,7 +503,7 @@ int dvb_write_format_oneline(const char *fname,
 				}
 				if (data >= table->size) {
 					sprintf(err_msg,
-						 "value not supported");
+						 _("value not supported"));
 					goto error;
 				}
 
@@ -495,7 +513,7 @@ int dvb_write_format_oneline(const char *fname,
 				case DTV_VIDEO_PID:
 					if (!entry->video_pid) {
 						fprintf(stderr,
-							"WARNING: missing video PID while parsing entry %d of %s\n",
+							_("WARNING: missing video PID while parsing entry %d of %s\n"),
 							line, fname);
 						fprintf(fp, "%d",0);
 					} else
@@ -505,7 +523,7 @@ int dvb_write_format_oneline(const char *fname,
 				case DTV_AUDIO_PID:
 					if (!entry->audio_pid) {
 						fprintf(stderr,
-							"WARNING: missing audio PID while parsing entry %d of %s\n",
+							_("WARNING: missing audio PID while parsing entry %d of %s\n"),
 							line, fname);
 						fprintf(fp, "%d",0);
 					} else
@@ -524,7 +542,7 @@ int dvb_write_format_oneline(const char *fname,
 							data = fmt->table[i].default_value;
 						} else {
 							fprintf(stderr,
-								"property %s not supported while parsing entry %d of %s\n",
+								_("property %s not supported while parsing entry %d of %s\n"),
 								dvb_cmd_name(table->prop),
 								line, fname);
 							data = 0;
@@ -545,7 +563,7 @@ int dvb_write_format_oneline(const char *fname,
 	return 0;
 
 error:
-	fprintf(stderr, "ERROR: %s while parsing entry %d of %s\n",
+	fprintf(stderr, _("ERROR: %s while parsing entry %d of %s\n"),
 		 err_msg, line, fname);
 	fclose(fp);
 	return -1;
@@ -617,6 +635,14 @@ static int fill_entry(struct dvb_entry *entry, char *key, char *value)
 		return 0;
 	}
 
+	if (!strcasecmp(key, "COUNTRY")) {
+		enum dvb_country_t id = dvb_country_a2_to_id(value);
+		if (id == COUNTRY_UNKNOWN)
+			return -2;
+		dvb_store_entry_prop(entry, DTV_COUNTRY_CODE, id);
+		return 0;
+	}
+
 	if (!strcasecmp(key, "VIDEO_PID"))
 		is_video = 1;
 	else if (!strcasecmp(key, "AUDIO_PID"))
@@ -718,7 +744,7 @@ struct dvb_file *dvb_read_file(const char *fname)
 
 	dvb_file = calloc(sizeof(*dvb_file), 1);
 	if (!dvb_file) {
-		perror("Allocating memory for dvb_file");
+		perror(_("Allocating memory for dvb_file"));
 		return NULL;
 	}
 
@@ -754,7 +780,7 @@ struct dvb_file *dvb_read_file(const char *fname)
 			p++;
 			p = strtok(p, "]");
 			if (!p) {
-				sprintf(err_msg, "Missing channel group");
+				sprintf(err_msg, _("Missing channel group"));
 				goto error;
 			}
 			if (!strcasecmp(p, CHANNEL))
@@ -767,12 +793,12 @@ struct dvb_file *dvb_read_file(const char *fname)
 			}
 		} else {
 			if (!entry) {
-				sprintf(err_msg, "key/value without a channel group");
+				sprintf(err_msg, _("key/value without a channel group"));
 				goto error;
 			}
 			key = strtok(p, "=");
 			if (!key) {
-				sprintf(err_msg, "missing key");
+				sprintf(err_msg, _("missing key"));
 				goto error;
 			}
 			p = &key[strlen(key) - 1];
@@ -781,7 +807,7 @@ struct dvb_file *dvb_read_file(const char *fname)
 			*p = 0;
 			value = strtok(NULL, "\n");
 			if (!value) {
-				sprintf(err_msg, "missing value");
+				sprintf(err_msg, _("missing value"));
 				goto error;
 			}
 			while (*value == ' ' || *value == '\t')
@@ -789,7 +815,7 @@ struct dvb_file *dvb_read_file(const char *fname)
 
 			rc = fill_entry(entry, key, value);
 			if (rc == -2) {
-				sprintf(err_msg, "value %s is invalid for %s",
+				sprintf(err_msg, _("value %s is invalid for %s"),
 					value, key);
 				goto error;
 			}
@@ -803,7 +829,7 @@ struct dvb_file *dvb_read_file(const char *fname)
 	return dvb_file;
 
 error:
-	fprintf (stderr, "ERROR %s while parsing line %d of %s\n",
+	fprintf (stderr, _("ERROR %s while parsing line %d of %s\n"),
 		 err_msg, line, fname);
 	if (buf)
 		free(buf);
@@ -884,6 +910,8 @@ int dvb_write_file(const char *fname, struct dvb_file *dvb_file)
 
 		for (i = 0; i < entry->n_props; i++) {
 			const char * const *attr_name = dvb_attr_names(entry->props[i].cmd);
+			const char *buf;
+
 			if (attr_name) {
 				int j;
 
@@ -894,6 +922,11 @@ int dvb_write_file(const char *fname, struct dvb_file *dvb_file)
 				}
 			}
 
+			if (entry->props[i].cmd == DTV_COUNTRY_CODE) {
+				buf = dvb_country_to_2letters(entry->props[i].u.data);
+				attr_name = &buf;
+			}
+
 			/* Handle parameters with optional values */
 			switch (entry->props[i].cmd) {
 			case DTV_PLS_CODE:
@@ -1085,7 +1118,7 @@ static int get_program_and_store(struct dvb_v5_fe_parms_priv *parms,
 		}
 	}
 	if (!found) {
-		dvb_logwarn("Channel %s (service ID %d) not found on PMT. Skipping it.",
+		dvb_logwarn(_("Channel %s (service ID %d) not found on PMT. Skipping it."),
 			    channel, service_id);
 		if (channel)
 			free(channel);
@@ -1103,7 +1136,7 @@ static int get_program_and_store(struct dvb_v5_fe_parms_priv *parms,
 		entry = entry->next;
 	}
 	if (!entry) {
-		dvb_logerr("Not enough memory");
+		dvb_logerr(_("Not enough memory"));
 		if (channel)
 			free(channel);
 		if (vchannel)
@@ -1132,12 +1165,26 @@ static int get_program_and_store(struct dvb_v5_fe_parms_priv *parms,
 				usleep(100000);
 		} while (rc == EAGAIN);
 		if (rc)
-			dvb_logerr("Couldn't get frontend props");
+			dvb_logerr(_("Couldn't get frontend props"));
 	}
 	for (j = 0; j < parms->n_props; j++) {
 		entry->props[j].cmd = parms->dvb_prop[j].cmd;
 		entry->props[j].u.data = parms->dvb_prop[j].u.data;
 
+		/* [ISDB-S]
+		 * Update DTV_STREAM_ID if it was not specified by a user
+		 * or set to a wrong one.
+		 * In those cases, demod must have selected the first TS_ID.
+		 * The update must be after the above dvb_fe_get_parms() call,
+		 * since a lazy FE driver that does not update stream_id prop
+		 * cache in FE.get_frontend() may overwrite the setting again
+		 * with the initial / user-specified wrong value.
+		 */
+		if (entry->props[j].cmd == DTV_STREAM_ID
+		    && entry->props[j].u.data == 0
+		    && parms->p.current_sys == SYS_ISDBS)
+			entry->props[j].u.data = dvb_scan_handler->pat->header.id;
+
 		if (!channel && entry->props[j].cmd == DTV_FREQUENCY)
 			freq = parms->dvb_prop[j].u.data;
 	}
@@ -1147,7 +1194,7 @@ static int get_program_and_store(struct dvb_v5_fe_parms_priv *parms,
 			service_id);
 		if (r < 0)
 			dvb_perror("asprintf");
-		dvb_log("Storing Service ID %d: '%s'", service_id, channel);
+		dvb_log(_("Storing Service ID %d: '%s'"), service_id, channel);
 	}
 	entry->n_props = parms->n_props;
 	entry->channel = channel;
@@ -1162,20 +1209,20 @@ static int get_program_and_store(struct dvb_v5_fe_parms_priv *parms,
 
 /* Service type, according with EN 300 468 V1.3.1 (1998-02) */
 static char *sdt_services[256] = {
-	[0x00 ...0xff] = "reserved",
-	[0x01] = "digital television",
-	[0x02] = "digital radio",
-	[0x03] = "Teletext",
-	[0x04] = "NVOD reference",
-	[0x05] = "NVOD time-shifted",
-	[0x06] = "mosaic",
-	[0x07] = "PAL coded signal",
-	[0x08] = "SECAM coded signal",
-	[0x09] = "D/D2-MAC",
-	[0x0a] = "FM Radio",
-	[0x0b] = "NTSC coded signal",
-	[0x0c] = "data broadcast",
-	[0x80 ...0xfe] = "user defined",
+	[0x00 ...0xff] = N_("reserved"),
+	[0x01] = N_("digital television"),
+	[0x02] = N_("digital radio"),
+	[0x03] = N_("Teletext"),
+	[0x04] = N_("NVOD reference"),
+	[0x05] = N_("NVOD time-shifted"),
+	[0x06] = N_("mosaic"),
+	[0x07] = N_("PAL coded signal"),
+	[0x08] = N_("SECAM coded signal"),
+	[0x09] = N_("D/D2-MAC"),
+	[0x0a] = N_("FM Radio"),
+	[0x0b] = N_("NTSC coded signal"),
+	[0x0c] = N_("data broadcast"),
+	[0x80 ...0xfe] = N_("user defined"),
 };
 
 int dvb_store_channel(struct dvb_file **dvb_file,
@@ -1189,7 +1236,7 @@ int dvb_store_channel(struct dvb_file **dvb_file,
 	if (!*dvb_file) {
 		*dvb_file = calloc(sizeof(**dvb_file), 1);
 		if (!*dvb_file) {
-			dvb_perror("Allocating memory for dvb_file");
+			dvb_perror(_("Allocating memory for dvb_file"));
 			return -1;
 		}
 	}
@@ -1213,7 +1260,7 @@ int dvb_store_channel(struct dvb_file **dvb_file,
 				dvb_perror("asprintf");
 
 			if (parms->p.verbose)
-				dvb_log("Virtual channel %s, name = %s",
+				dvb_log(_("Virtual channel %s, name = %s"),
 					vchannel, channel);
 
 			rc = get_program_and_store(parms, *dvb_file, dvb_scan_handler,
@@ -1240,7 +1287,7 @@ int dvb_store_channel(struct dvb_file **dvb_file,
 
 			service_id = dvb_scan_handler->program[i].pat_pgm->service_id;
 			if (!warned) {
-				dvb_log("WARNING: no SDT table - storing channel(s) without their names");
+				dvb_log(_("WARNING: no SDT table - storing channel(s) without their names"));
 				warned = 1;
 			}
 
@@ -1267,9 +1314,9 @@ int dvb_store_channel(struct dvb_file **dvb_file,
 				channel = calloc(strlen(p) + 1, 1);
 				strcpy(channel, p);
 			}
-			dvb_log("Service %s, provider %s: %s",
+			dvb_log(_("Service %s, provider %s: %s"),
 				desc->name, desc->provider,
-				sdt_services[desc->service_type]);
+				_(sdt_services[desc->service_type]));
 			break;
 		}
 
@@ -1280,7 +1327,7 @@ int dvb_store_channel(struct dvb_file **dvb_file,
 		}
 
 		if (parms->p.verbose)
-			dvb_log("Storing as channel %s", channel);
+			dvb_log(_("Storing as channel %s"), channel);
 		vchannel = dvb_vchannel(parms, dvb_scan_handler->nit, service->service_id);
 
 		rc = get_program_and_store(parms, *dvb_file, dvb_scan_handler,
@@ -1305,7 +1352,7 @@ enum dvb_file_formats dvb_parse_format(const char *name)
 	if (!strcasecmp(name, "VDR"))
 		return FILE_VDR;
 
-	fprintf(stderr, "File format %s is unknown\n", name);
+	fprintf(stderr, _("File format %s is unknown\n"), name);
 	return FILE_UNKNOWN;
 }
 
@@ -1323,7 +1370,8 @@ static struct {
 	{ SYS_ISDBS,		"ISDB-S" },
 	{ SYS_ISDBT,		"ISDB-T" },
 	{ SYS_ATSCMH,		"ATSC-MH" },
-	{ SYS_DMBTH,		"DMB-TH" },
+	{ SYS_DTMB,		"DMB-TH" },
+	{ SYS_DTMB,		"DMB" },
 };
 
 int dvb_parse_delsys(const char *name)
@@ -1349,7 +1397,7 @@ int dvb_parse_delsys(const char *name)
 	 * Not found. Print all possible values, except for
 	 * SYS_UNDEFINED.
 	 */
-	fprintf(stderr, "ERROR: Delivery system %s is not known. Valid values are:\n",
+	fprintf(stderr, _("ERROR: Delivery system %s is not known. Valid values are:\n"),
 		name);
 	for (i = 0; i < ARRAY_SIZE(alt_names) - 1; i++) {
 		if (!(cnt % 5))
@@ -1393,10 +1441,10 @@ struct dvb_file *dvb_read_file_format(const char *fname,
 		break;
 	case FILE_VDR:
 		/* FIXME: add support for VDR input */
-		fprintf(stderr, "Currently, VDR format is supported only for output\n");
+		fprintf(stderr, _("Currently, VDR format is supported only for output\n"));
 		return NULL;
 	default:
-		fprintf(stderr, "Format is not supported\n");
+		fprintf(stderr, _("Format is not supported\n"));
 		return NULL;
 	}
 
