@@ -807,28 +807,28 @@ static uint32_t rds_decode_group0(struct rds_private_state *priv_state)
 
 	/* bit 2 of block B contains 1 bit of the Decoder Control Information (DI)
 	 * the segment number defines the bit position
-	 * New bits are only accepted the segments arrive in the correct order */
+	 * New bits are only accepted if the segments arrive in the correct order */
 	bool bit2 = grp->data_b_lsb & 0x04;
 	if (segment == 0 || segment == priv_state->next_di_segment) {
 		switch (segment) {
 		case 0:
 			priv_state->new_di = set_bit(priv_state->new_di,
-				V4L2_RDS_FLAG_STEREO, bit2);
+				V4L2_RDS_FLAG_DYNAMIC_PTY, bit2);
 			priv_state->next_di_segment = 1;
 			break;
 		case 1:
 			priv_state->new_di = set_bit(priv_state->new_di,
-				V4L2_RDS_FLAG_ARTIFICIAL_HEAD, bit2);
+				V4L2_RDS_FLAG_COMPRESSED, bit2);
 			priv_state->next_di_segment = 2;
 			break;
 		case 2:
 			priv_state->new_di = set_bit(priv_state->new_di,
-				V4L2_RDS_FLAG_COMPRESSED, bit2);
+				V4L2_RDS_FLAG_ARTIFICIAL_HEAD, bit2);
 			priv_state->next_di_segment = 3;
 			break;
 		case 3:
 			priv_state->new_di = set_bit(priv_state->new_di,
-				V4L2_RDS_FLAG_DYNAMIC_PTY, bit2);
+				V4L2_RDS_FLAG_STEREO, bit2);
 			/* check if the value of DI has changed, and store
 			 * and signal DI update in case */
 			if (handle->di != priv_state->new_di) {
@@ -1022,10 +1022,10 @@ static time_t rds_decode_mjd(const struct rds_private_state *priv_state)
 	/* add / subtract the local offset to get the local time.
 	 * The offset is expressed in multiples of half hours */
 	if (priv_state->utc_offset & 0x20) { /* bit 5 indicates -/+ */
-		local_hour -= (offset * 2);
+		local_hour -= offset / 2;
 		local_minute -= (offset % 2) * 30;
 	} else {
-		local_hour += (offset * 2);
+		local_hour += offset / 2;
 		local_minute += (offset % 2) * 30;
 	}
 
@@ -1044,14 +1044,14 @@ static time_t rds_decode_mjd(const struct rds_private_state *priv_state)
 	new_time.tm_min = local_minute;
 	new_time.tm_hour = local_hour;
 	new_time.tm_mday = d;
-	new_time.tm_mon = m;
+	new_time.tm_mon = m - 1;
 	new_time.tm_year = y;
 	/* offset (submitted by RDS) that was used to compute the local time,
 	 * expressed in multiples of half hours, bit 5 indicates -/+ */
 	if (priv_state->utc_offset & 0x20)
-		new_time.tm_gmtoff = -2 * offset * 3600;
+		new_time.tm_gmtoff = -offset * 1800;
 	else
-		new_time.tm_gmtoff = 2 * offset * 3600;
+		new_time.tm_gmtoff = offset * 1800;
 
 	/* convert tm struct to time_t value and return it */
 	return mktime(&new_time);
@@ -1388,7 +1388,8 @@ uint32_t v4l2_rds_add(struct v4l2_rds *handle, struct v4l2_rds_data *rds_data)
 
 	rds_stats->block_cnt++;
 	/* check for corrected / uncorrectable errors in the data */
-	if (rds_data->block & V4L2_RDS_BLOCK_ERROR) {
+	if ((rds_data->block & V4L2_RDS_BLOCK_ERROR) ||
+	    block_id == V4L2_RDS_BLOCK_INVALID) {
 		block_id = -1;
 		rds_stats->block_error_cnt++;
 	} else if (rds_data->block & V4L2_RDS_BLOCK_CORRECTED) {
@@ -1583,7 +1584,8 @@ const char *v4l2_rds_get_language_str(const struct v4l2_rds *handle)
 const char *v4l2_rds_get_coverage_str(const struct v4l2_rds *handle)
 {
 	/* bits 8-11 contain the area coverage code */
-	uint8_t coverage = (handle->pi >> 8) & 0X0f;
+	uint8_t coverage = (handle->pi >> 8) & 0x0f;
+	uint8_t nibble = (handle->pi >> 12) & 0x0f;
 	static const char *coverage_lut[16] = {
 		"Local", "International", "National", "Supra-Regional",
 		"Regional 1", "Regional 2", "Regional 3", "Regional 4",
@@ -1591,7 +1593,14 @@ const char *v4l2_rds_get_coverage_str(const struct v4l2_rds *handle)
 		"Regional 9", "Regional 10", "Regional 11", "Regional 12"
 	};
 
-	return coverage_lut[coverage];
+	/*
+	 * Coverage area codes are restricted to the B, D and E PI code
+	 * blocks for RBDS.
+	 */
+	if (!handle->is_rbds ||
+	    (nibble == 0xb || nibble == 0xd || nibble == 0xe))
+		return coverage_lut[coverage];
+	return "Not Available";
 }
 
 const struct v4l2_rds_group *v4l2_rds_get_group(const struct v4l2_rds *handle)
