@@ -16,7 +16,11 @@
 # Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335  USA
  */
 
+#ifdef ANDROID
+#include <android-config.h>
+#else
 #include <config.h>
+#endif
 #include <errno.h>
 #include <string.h>
 #include <stdlib.h>
@@ -135,6 +139,7 @@ static const struct v4lconvert_pixfmt supported_src_pixfmts[] = {
 	{ V4L2_PIX_FMT_Y6,		 8,	20,	20,	0 },
 	{ V4L2_PIX_FMT_Y10BPACK,	10,	20,	20,	0 },
 	{ V4L2_PIX_FMT_Y16,		16,	20,	20,	0 },
+	{ V4L2_PIX_FMT_Y16_BE,		16,	20,	20,	0 },
 };
 
 static const struct v4lconvert_pixfmt supported_dst_pixfmts[] = {
@@ -430,7 +435,7 @@ static int v4lconvert_do_try_format_uvc(struct v4lconvert_data *data,
 	   so we should be able to get away with this. */
 	dest_fmt->fmt.pix.bytesperline = 0;
 	dest_fmt->fmt.pix.sizeimage = 0;
-	dest_fmt->fmt.pix.colorspace = 0;
+	dest_fmt->fmt.pix.colorspace = V4L2_COLORSPACE_DEFAULT;
 	dest_fmt->fmt.pix.priv = 0;
 
 	*src_fmt = *dest_fmt;
@@ -1001,6 +1006,7 @@ static int v4lconvert_convert_pixfmt(struct v4lconvert_data *data,
 	}
 
 	case V4L2_PIX_FMT_Y16:
+	case V4L2_PIX_FMT_Y16_BE:
 		if (src_size < (width * height * 2)) {
 			V4LCONVERT_ERR("short y16 data frame\n");
 			errno = EPIPE;
@@ -1009,11 +1015,13 @@ static int v4lconvert_convert_pixfmt(struct v4lconvert_data *data,
 		switch (dest_pix_fmt) {
 		case V4L2_PIX_FMT_RGB24:
 	        case V4L2_PIX_FMT_BGR24:
-			v4lconvert_y16_to_rgb24(src, dest, width, height);
+			v4lconvert_y16_to_rgb24(src, dest, width, height,
+					src_pix_fmt == V4L2_PIX_FMT_Y16);
 			break;
 		case V4L2_PIX_FMT_YUV420:
 		case V4L2_PIX_FMT_YVU420:
-			v4lconvert_y16_to_yuv420(src, dest, fmt);
+			v4lconvert_y16_to_yuv420(src, dest, fmt,
+					 src_pix_fmt == V4L2_PIX_FMT_Y16);
 			break;
 		}
 		break;
