@@ -588,11 +588,12 @@ void v4lconvert_rgb565_to_yuv420(const unsigned char *src, unsigned char *dest,
 }
 
 void v4lconvert_y16_to_rgb24(const unsigned char *src, unsigned char *dest,
-		int width, int height)
+		int width, int height, int little_endian)
 {
 	int j;
 
-	src++; /*Y16 is little endian*/
+	if (little_endian)
+		src++;
 
 	while (--height >= 0) {
 		for (j = 0; j < width; j++) {
@@ -605,11 +606,12 @@ void v4lconvert_y16_to_rgb24(const unsigned char *src, unsigned char *dest,
 }
 
 void v4lconvert_y16_to_yuv420(const unsigned char *src, unsigned char *dest,
-		const struct v4l2_format *src_fmt)
+		const struct v4l2_format *src_fmt, int little_endian)
 {
 	int x, y;
 
-	src++; /*Y16 is little endian*/
+	if (little_endian)
+		src++;
 
 	/* Y */
 	for (y = 0; y < src_fmt->fmt.pix.height; y++)
