@@ -14,13 +14,13 @@
 #
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Suite 500, Boston, MA  02110-1335  USA
 
 # Note this code was originally licensed under the GNU GPL instead of the
 # GNU LGPL, its license has been changed with permission, see the permission
 # mail at the end of this file.
 
-*/
+ */
 
 /*
  *	Decoder for compressed spca561 images
@@ -68,19 +68,20 @@ static int fun_A(int *bitfill)
 	refill(bitfill);
 	return ret;
 }
+
 static int fun_B(int *bitfill)
 {
-	static int tab1[] =
-	    { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 31, 31,
+	static int tab1[] = {
+		0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 31, 31,
 		31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31, 31,
-		    16, 17,
+		16, 17,
 		18,
 		19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30
 	};
-	static int tab[] =
-	    { 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, -5,
+	static int tab[] = {
+		4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, -5,
 		-6, -7, -8, -9, -10, -11, -12, -13, -14, -15, -16, -17,
-		    -18, -19
+		-18, -19
 	};
 	unsigned int tmp;
 
@@ -90,17 +91,18 @@ static int fun_B(int *bitfill)
 		return 0xff;
 	return tab[tab1[tmp]];
 }
+
 static int fun_C(int *bitfill, int gkw)
 {
-	static int tab1[] =
-	    { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 23, 23, 23, 23, 23, 23,
+	static int tab1[] = {
+		0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 23, 23, 23, 23, 23, 23,
 		23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23, 23,
-		    12, 13,
+		12, 13,
 		14,
 		15, 16, 17, 18, 19, 20, 21, 22
 	};
-	static int tab[] =
-	    { 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, -9, -10, -11,
+	static int tab[] = {
+		8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, -9, -10, -11,
 		-12, -13, -14, -15, -16, -17, -18, -19
 	};
 	unsigned int tmp;
@@ -122,6 +124,7 @@ static int fun_C(int *bitfill, int gkw)
 	refill(bitfill);
 	return tab[tab1[tmp]];
 }
+
 static int fun_D(int *bitfill, int gkw)
 {
 	if (gkw == 0xfd) {
@@ -301,445 +304,445 @@ static int fun_F(int cur_byte, int *bitfill)
 }
 
 static int internal_spca561_decode(int width, int height,
-				   const unsigned char *inbuf,
-				   unsigned char *outbuf)
+		const unsigned char *inbuf,
+		unsigned char *outbuf)
 {
 	/* buffers */
 	static int accum[8 * 8 * 8];
 	static int i_hits[8 * 8 * 8];
 
-	static const int nbits_A[] =
-	    { 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+	static const int nbits_A[] = {
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
+		1, 1,
 		1, 1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1, 1,
 		8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 0, 0, 7, 7,
-		    7, 7,
+		7, 7,
 		7, 7, 7, 7, 7,
 		7, 7, 7, 7, 7, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5,
-		    5, 5,
+		5, 5,
 		5, 5, 5, 5, 5,
 		5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
 	};
-	static const int tab_A[] =
-	    { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	static const int tab_A[] = {
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 11, -11, 4, 4, 5, 5, 6, 6, 7, 7, 8, 8, 9, 9,
-		    10, 10,
+		10, 10,
 		255, 254, -4,
 		-4, -5, -5, -6, -6, -7, -7, -8, -8, -9, -9, -10, -10, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1, -1,
 		-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1,
 		-1, -1, -1, -1, -1, -1, -1, 2, 2, 2, 2, 2, 2, 2, 2, 3, 3,
-		    3, 3, 3,
+		3, 3, 3,
 		3, 3, 3,
 		-2, -2, -2, -2, -2, -2, -2, -2, -3, -3, -3, -3, -3, -3, -3,
-		    -3, 1,
+		-3, 1,
 		1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1,
 		1
 	};
 
-	static const int nbits_B[] =
-	    { 0, 8, 7, 7, 6, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5, 4, 4, 4, 4,
+	static const int nbits_B[] = {
+		0, 8, 7, 7, 6, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5, 4, 4, 4, 4,
 		4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 3, 3, 3, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2,
-		    2, 2,
+		2, 2,
 		2, 2, 2, 2, 2,
 		2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
-		    2, 2,
+		2, 2,
 		2, 2, 2, 2, 2,
 		2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
-		    2, 2,
+		2, 2,
 		2, 2, 2, 2, 2,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
 	};
-	static const int tab_B[] =
-	    { 0xff, -4, 3, 3, -3, -3, -3, -3, 2, 2, 2, 2, 2, 2, 2, 2, -2,
+	static const int tab_B[] = {
+		0xff, -4, 3, 3, -3, -3, -3, -3, 2, 2, 2, 2, 2, 2, 2, 2, -2,
 		-2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1,
 		-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1,
 		-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1,
 		-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1,
 		-1, -1, -1, -1, -1, -1, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0, 0,
+		0, 0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0,
 	};
 
-	static const int nbits_C[] =
-	    { 0, 0, 8, 8, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5, 5, 5,
+	static const int nbits_C[] = {
+		0, 0, 8, 8, 7, 7, 7, 7, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5, 5, 5,
 		5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 4, 4, 4, 4, 4, 4, 4, 4,
-		    4, 4,
+		4, 4,
 		4, 4, 4, 4, 4,
 		4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
-		    2, 2,
+		2, 2,
 		2, 2, 2, 2, 2,
 		2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
-		    2, 2,
+		2, 2,
 		2, 2, 2, 2, 2,
 		2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
-		    2, 2,
+		2, 2,
 		2, 2, 2, 2, 2,
 		2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
-		    2, 2,
+		2, 2,
 		2, 2, 2, 2, 2,
 		2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
 	};
-	static const int tab_C[] =
-	    { 0xff, 0xfe, 6, -7, 5, 5, -6, -6, 4, 4, 4, 4, -5, -5, -5, -5,
+	static const int tab_C[] = {
+		0xff, 0xfe, 6, -7, 5, 5, -6, -6, 4, 4, 4, 4, -5, -5, -5, -5,
 		3, 3, 3, 3, 3, 3, 3, 3, -4, -4, -4, -4, -4, -4, -4, -4, 2,
-		    2, 2, 2,
+		2, 2, 2,
 		2, 2, 2,
 		2, 2, 2, 2, 2, 2, 2, 2, 2, -3, -3, -3, -3, -3, -3, -3, -3,
-		    -3, -3,
+		-3, -3,
 		-3, -3, -3,
 		-3, -3, -3, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1,
+		1, 1,
 		1, 1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, 1, -2, -2, -2, -2, -2, -2, -2,
-		    -2, -2,
+		-2, -2,
 		-2, -2, -2,
 		-2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2,
-		    -2, -2,
+		-2, -2,
 		-2, -2,
 		-2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0, 0,
+		0, 0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1, -1,
 		-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1,
 		-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1,
 		-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-		    -1,
+		-1,
 	};
 
-	static const int nbits_D[] =
-	    { 0, 0, 0, 0, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6,
+	static const int nbits_D[] = {
+		0, 0, 0, 0, 8, 8, 8, 8, 7, 7, 7, 7, 7, 7, 7, 7, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5, 5, 5, 5, 5, 5, 5,
-		    5, 5,
+		5, 5,
 		5, 5, 5, 5, 5,
 		5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 5, 4, 4, 4,
-		    4, 4,
+		4, 4,
 		4, 4, 4, 4, 4,
 		4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
-		    4, 4,
+		4, 4,
 		4, 4, 4, 4, 4,
 		4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4, 4,
-		    4, 4,
+		4, 4,
 		4, 4, 4, 4, 4,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3
 	};
-	static const int tab_D[] =
-	    { 0xff, 0xfe, 0xfd, 0xfc, 10, -11, 11, -12, 8, 8, -9, -9, 9, 9,
+	static const int tab_D[] = {
+		0xff, 0xfe, 0xfd, 0xfc, 10, -11, 11, -12, 8, 8, -9, -9, 9, 9,
 		-10, -10, 6, 6, 6, 6, -7, -7, -7, -7, 7, 7, 7, 7, -8, -8,
-		    -8, -8,
+		-8, -8,
 		4, 4, 4, 4,
 		4, 4, 4, 4, -5, -5, -5, -5, -5, -5, -5, -5, 5, 5, 5, 5, 5,
-		    5, 5, 5,
+		5, 5, 5,
 		-6, -6,
 		-6, -6, -6, -6, -6, -6, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2,
-		    2, 2,
+		2, 2,
 		2, 2, -3,
 		-3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3, -3,
-		    3, 3,
+		3, 3,
 		3, 3, 3, 3,
 		3, 3, 3, 3, 3, 3, 3, 3, 3, 3, -4, -4, -4, -4, -4, -4, -4,
-		    -4, -4,
+		-4, -4,
 		-4, -4, -4,
 		-4, -4, -4, -4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0, 0,
+		0, 0, 0,
 		0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, -1, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1, -1,
 		-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,
-		    -1, -1,
+		-1, -1,
 		-1, -1,
 		-1, -1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-		    1, 1, 1,
+		1, 1, 1,
 		1, 1, 1,
 		1, 1, 1, 1, 1, 1, 1, 1, 1, -2, -2, -2, -2, -2, -2, -2, -2,
-		    -2, -2,
+		-2, -2,
 		-2, -2, -2,
 		-2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2, -2,
-		    -2, -2,
+		-2, -2,
 		-2, -2
 	};
 
 	/* a_curve[19 + i] = ... [-19..19] => [-160..160] */
-	static const int a_curve[] =
-	    { -160, -144, -128, -112, -98, -88, -80, -72, -64, -56, -48,
+	static const int a_curve[] = {
+		-160, -144, -128, -112, -98, -88, -80, -72, -64, -56, -48,
 		-40, -32, -24, -18, -12, -8, -5, -2, 0, 2, 5, 8, 12, 18,
-		    24, 32,
+		24, 32,
 		40, 48, 56, 64,
 		72, 80, 88, 98, 112, 128, 144, 160
 	};
 	/* clamp0_255[256 + i] = min(max(i,255),0) */
-	static const unsigned char clamp0_255[] =
-	    { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+	static const unsigned char clamp0_255[] = {
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
+		0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    0, 0,
+		0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0,
 		0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-		    1, 2,
+		1, 2,
 		3, 4, 5, 6, 7, 8, 9, 10,
 		11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25,
-		    26, 27,
+		26, 27,
 		28, 29, 30, 31, 32, 33,
 		34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48,
-		    49, 50,
+		49, 50,
 		51, 52, 53, 54, 55, 56,
 		57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71,
-		    72, 73,
+		72, 73,
 		74, 75, 76, 77, 78, 79,
 		80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94,
-		    95, 96,
+		95, 96,
 		97, 98, 99, 100, 101,
 		102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113,
-		    114,
+		114,
 		115, 116, 117, 118, 119,
 		120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131,
-		    132,
+		132,
 		133, 134, 135, 136, 137,
 		138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149,
-		    150,
+		150,
 		151, 152, 153, 154, 155,
 		156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167,
-		    168,
+		168,
 		169, 170, 171, 172, 173,
 		174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185,
-		    186,
+		186,
 		187, 188, 189, 190, 191,
 		192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203,
-		    204,
+		204,
 		205, 206, 207, 208, 209,
 		210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221,
-		    222,
+		222,
 		223, 224, 225, 226, 227,
 		228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239,
-		    240,
+		240,
 		241, 242, 243, 244, 245,
 		246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255, 255, 255, 255, 255,
 		255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
-		    255,
+		255,
 		255
 	};
 	/* abs_clamp15[19 + i] = min(abs(i), 15) */
-	static const int abs_clamp15[] =
-	    { 15, 15, 15, 15, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3,
+	static const int abs_clamp15[] = {
+		15, 15, 15, 15, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3,
 		2, 1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15,
-		    15, 15,
+		15, 15,
 		15
 	};
 	/* diff_encoding[256 + i] = ... */
-	static const int diff_encoding[] =
-	    { 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+	static const int diff_encoding[] = {
 		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
-		    7, 7,
+		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
+		7, 7,
 		7, 7, 7, 7, 7, 7, 7,
 		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
-		    7, 7,
+		7, 7,
 		7, 7, 7, 7, 7, 7, 7,
 		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
-		    7, 7,
+		7, 7,
 		7, 7, 7, 7, 7, 7, 7,
 		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
-		    7, 7,
+		7, 7,
 		7, 7, 7, 7, 7, 7, 7,
 		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
-		    7, 7,
+		7, 7,
 		7, 7, 7, 7, 7, 7, 7,
 		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
-		    7, 7,
+		7, 7,
 		7, 7, 7, 7, 7, 7, 7,
 		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7,
-		    7, 7,
+		7, 7,
 		7, 7, 7, 7, 7, 7, 7,
 		7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 7, 5, 5, 5, 5, 5, 5, 5,
-		    5, 5,
+		5, 5,
 		5, 5, 5, 5, 5, 3, 3,
 		3, 3, 1, 1, 0, 2, 2, 4, 4, 4, 4, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6, 6,
 		6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6, 6,
-		    6, 6,
+		6, 6,
 		6, 6, 6, 6, 6, 6
 	};
 
@@ -802,11 +805,11 @@ static int internal_spca561_decode(int width, int height,
 
 			if (pixel_x < 2) {
 				pixel_L = pixel_UL = pixel_U =
-				    output_ptr[-xwidth * 2];
+					output_ptr[-xwidth * 2];
 				pixel_UR = output_ptr[off_up_right];
 				dL = dC = 0;
 				dR = diff_encoding[0x100 + pixel_UR -
-						   pixel_U];
+					pixel_U];
 			} else if (pixel_x > width - 3)
 				dR = 0;
 
@@ -814,13 +817,13 @@ static int internal_spca561_decode(int width, int height,
 			index = dR + dC * 8 + dL * 64;
 
 			if (pixel_L + pixel_U * 2 <= 144
-			    && (pixel_y & 1) == 0
-			    && (b_it & 3) == 0 && (dR < 5) && (dC < 5)
-			    && (dL < 5)) {
+					&& (pixel_y & 1) == 0
+					&& (b_it & 3) == 0 && (dR < 5) && (dC < 5)
+					&& (dL < 5)) {
 				multiplier = 1;
 			} else if (pixel_L <= 48
-				   && dL <= 4 && dC <= 4 && dL >= 1
-				   && dC >= 1) {
+					&& dL <= 4 && dC <= 4 && dL >= 1
+					&& dC >= 1) {
 				multiplier = 2;
 			} else if (var_7 == 1) {
 				multiplier = 2;
@@ -861,14 +864,14 @@ static int internal_spca561_decode(int width, int height,
 				int tmp1, tmp2;
 
 				tmp1 =
-				    (pixel_U + pixel_L) * 3 - pixel_UL * 2;
+					(pixel_U + pixel_L) * 3 - pixel_UL * 2;
 				tmp1 += (tmp1 < 0) ? 3 : 0;
 				tmp2 = a_curve[19 + gkw] * multiplier;
 				tmp2 += (tmp2 < 0) ? 1 : 0;
 
 				*(output_ptr++) =
-				    clamp0_255[0x100 + (tmp1 >> 2) -
-					       (tmp2 >> 1)];
+					clamp0_255[0x100 + (tmp1 >> 2) -
+					(tmp2 >> 1)];
 			}
 			pixel_U = saved_pixel_UR;
 			saved_pixel_UR = pixel_UR;
@@ -893,36 +896,37 @@ static int internal_spca561_decode(int width, int height,
 /* FIXME, change internal_spca561_decode not to need the extra border
    around its dest buffer */
 void v4lconvert_decode_spca561(const unsigned char *inbuf,
-  unsigned char *outbuf, int width, int height)
+		unsigned char *outbuf, int width, int height)
 {
 	int i;
 	static unsigned char tmpbuf[650 * 490];
+
 	if (internal_spca561_decode(width, height, inbuf, tmpbuf) != 0)
 		return;
 	for (i = 0; i < height; i++)
 		memcpy(outbuf + i * width,
-		       tmpbuf + (i + 2) * (width + 6) + 3, width);
+				tmpbuf + (i + 2) * (width + 6) + 3, width);
 }
 
 /*************** License Change Permission Notice ***************
 
-Return-Path: <qq@kuku.eu.org>
+  Return-Path: <qq@kuku.eu.org>
 Received: from koko.hhs.nl ([145.52.2.16] verified)
-  by hhs.nl (CommuniGate Pro SMTP 4.3.6)
-  with ESMTP id 88574071 for j.w.r.degoede@hhs.nl; Mon, 16 Jun 2008 16:36:24 +0200
+by hhs.nl (CommuniGate Pro SMTP 4.3.6)
+with ESMTP id 88574071 for j.w.r.degoede@hhs.nl; Mon, 16 Jun 2008 16:36:24 +0200
 Received: from exim (helo=koko)
-	by koko.hhs.nl with local-smtp (Exim 4.62)
-	(envelope-from <qq@kuku.eu.org>)
-	id 1K8Fom-0002iJ-3K
-	for j.w.r.degoede@hhs.nl; Mon, 16 Jun 2008 16:36:24 +0200
+by koko.hhs.nl with local-smtp (Exim 4.62)
+(envelope-from <qq@kuku.eu.org>)
+id 1K8Fom-0002iJ-3K
+for j.w.r.degoede@hhs.nl; Mon, 16 Jun 2008 16:36:24 +0200
 Received: from [192.87.102.74] (port=41377 helo=filter6-ams.mf.surf.net)
-	by koko.hhs.nl with esmtp (Exim 4.62)
-	(envelope-from <qq@kuku.eu.org>)
-	id 1K8Fol-0002iC-Qo
-	for j.w.r.degoede@hhs.nl; Mon, 16 Jun 2008 16:36:23 +0200
+by koko.hhs.nl with esmtp (Exim 4.62)
+(envelope-from <qq@kuku.eu.org>)
+id 1K8Fol-0002iC-Qo
+for j.w.r.degoede@hhs.nl; Mon, 16 Jun 2008 16:36:23 +0200
 Received: from kuku.eu.org (pa90.wielkopole.sdi.tpnet.pl [217.99.123.90])
-	by filter6-ams.mf.surf.net (8.13.8/8.13.8/Debian-3) with ESMTP id m5GEa55r001787
-	for <j.w.r.degoede@hhs.nl>; Mon, 16 Jun 2008 16:36:06 +0200
+by filter6-ams.mf.surf.net (8.13.8/8.13.8/Debian-3) with ESMTP id m5GEa55r001787
+for <j.w.r.degoede@hhs.nl>; Mon, 16 Jun 2008 16:36:06 +0200
 Received: (qmail 2243 invoked by uid 500); 16 Jun 2008 14:29:37 -0000
 Date: Mon, 16 Jun 2008 16:29:37 +0200 (CEST)
 From: Andrzej Szombierski <qq@kuku.eu.org>
@@ -976,7 +980,7 @@ and as an application developer I would be able to just request RGB data=20
 from any /dev/video*, right?
 
 > I do not want to license this library as GPL (as the current spca code is=
-), as=20
+		), as=20
 > it should be usable by as much software as possible. Instead I want to li=
 cense=20
 > it under the LGPL version 2.1 or later.
@@ -991,13 +995,13 @@ Also sounds reasonable.
 Yes, of course.=20
 
 > Thanks & Regards,
->=20
-> Hans
->=20
->
+	>=20
+	> Hans
+	>=20
+	>
 
---=20
-:: Andrzej Szombierski :: qq@kuku.eu.org :: http://kuku.eu.org ::
-:: anszom@bezkitu.com  :: radio bez kitu :: http://bezkitu.com ::
+	--=20
+	:: Andrzej Szombierski :: qq@kuku.eu.org :: http://kuku.eu.org ::
+	:: anszom@bezkitu.com  :: radio bez kitu :: http://bezkitu.com ::
 
-*/
+	*/
