@@ -181,7 +181,7 @@ struct parse_event key_events[] = {
 	{"KEY_WWW", 150},
 	{"KEY_MSDOS", 151},
 	{"KEY_COFFEE", 152},
-	{"KEY_DIRECTION", 153},
+	{"KEY_ROTATE_DISPLAY", 153},
 	{"KEY_CYCLEWINDOWS", 154},
 	{"KEY_MAIL", 155},
 	{"KEY_BOOKMARKS", 156},
@@ -479,6 +479,10 @@ struct parse_event key_events[] = {
 	{"KEY_NUMERIC_9", 0x209},
 	{"KEY_NUMERIC_STAR", 0x20a},
 	{"KEY_NUMERIC_POUND", 0x20b},
+	{"KEY_NUMERIC_A", 0x20c},
+	{"KEY_NUMERIC_B", 0x20d},
+	{"KEY_NUMERIC_C", 0x20e},
+	{"KEY_NUMERIC_D", 0x20f},
 	{"KEY_CAMERA_FOCUS", 0x210},
 	{"KEY_WPS_BUTTON", 0x211},
 	{"KEY_TOUCHPAD_TOGGLE", 0x212},
@@ -508,6 +512,12 @@ struct parse_event key_events[] = {
 	{"KEY_VOICECOMMAND", 0x246},
 	{"KEY_BRIGHTNESS_MIN", 0x250},
 	{"KEY_BRIGHTNESS_MAX", 0x251},
+	{"KEY_KBDINPUTASSIST_PREV", 0x260},
+	{"KEY_KBDINPUTASSIST_NEXT", 0x261},
+	{"KEY_KBDINPUTASSIST_PREVGROUP", 0x262},
+	{"KEY_KBDINPUTASSIST_NEXTGROUP", 0x263},
+	{"KEY_KBDINPUTASSIST_ACCEPT", 0x264},
+	{"KEY_KBDINPUTASSIST_CANCEL", 0x265},
 	{"BTN_TRIGGER_HAPPY", 0x2c0},
 	{"BTN_TRIGGER_HAPPY1", 0x2c0},
 	{"BTN_TRIGGER_HAPPY2", 0x2c1},
