@@ -45,6 +45,7 @@ static const __u32 buftype2cap[] = {
 	V4L2_CAP_VIDEO_CAPTURE_MPLANE | V4L2_CAP_VIDEO_M2M_MPLANE,
 	V4L2_CAP_VIDEO_OUTPUT_MPLANE | V4L2_CAP_VIDEO_M2M_MPLANE,
 	V4L2_CAP_SDR_CAPTURE,
+	V4L2_CAP_SDR_OUTPUT,
 };
 
 static int testEnumFrameIntervals(struct node *node, __u32 pixfmt,
@@ -220,7 +221,7 @@ static int testEnumFrameSizes(struct node *node, __u32 pixfmt)
 
 static int testEnumFormatsType(struct node *node, unsigned type)
 {
-	pixfmt_set &set = node->buftype_pixfmts[type];
+	pixfmt_map &map = node->buftype_pixfmts[type];
 	struct v4l2_fmtdesc fmtdesc;
 	unsigned f = 0;
 	int ret;
@@ -261,11 +262,11 @@ static int testEnumFormatsType(struct node *node, unsigned type)
 		f++;
 		if (type == V4L2_BUF_TYPE_PRIVATE)
 			continue;
-		// Update array in v4l2-compliance.h if new buffer types are added
-		assert(type <= V4L2_BUF_TYPE_SDR_CAPTURE);
-		if (set.find(fmtdesc.pixelformat) != set.end())
+		// Update define in v4l2-compliance.h if new buffer types are added
+		assert(type <= V4L2_BUF_TYPE_LAST);
+		if (map.find(fmtdesc.pixelformat) != map.end())
 			return fail("duplicate format %08x\n", fmtdesc.pixelformat);
-		set.insert(fmtdesc.pixelformat);
+		map[fmtdesc.pixelformat] = fmtdesc.flags;
 	}
 	info("found %d formats for buftype %d\n", f, type);
 	return 0;
@@ -277,7 +278,7 @@ int testEnumFormats(struct node *node)
 	unsigned type;
 	int ret;
 
-	for (type = 0; type <= V4L2_BUF_TYPE_SDR_CAPTURE; type++) {
+	for (type = 0; type <= V4L2_BUF_TYPE_LAST; type++) {
 		ret = testEnumFormatsType(node, type);
 		if (ret && ret != ENOTTY)
 			return ret;
@@ -290,6 +291,7 @@ int testEnumFormats(struct node *node)
 		case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
 		case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
 		case V4L2_BUF_TYPE_SDR_CAPTURE:
+		case V4L2_BUF_TYPE_SDR_OUTPUT:
 			if (ret && (node->g_caps() & buftype2cap[type]))
 				return fail("%s cap set, but no %s formats defined\n",
 						buftype2s(type).c_str(), buftype2s(type).c_str());
@@ -393,8 +395,8 @@ static void createInvalidFmt(struct v4l2_format &fmt, struct v4l2_clip &clip, un
 
 static int testFormatsType(struct node *node, int ret,  unsigned type, struct v4l2_format &fmt, bool have_clip = false)
 {
-	pixfmt_set &set = node->buftype_pixfmts[type];
-	pixfmt_set *set_splane;
+	pixfmt_map &map = node->buftype_pixfmts[type];
+	pixfmt_map *map_splane;
 	struct v4l2_pix_format &pix = fmt.fmt.pix;
 	struct v4l2_pix_format_mplane &pix_mp = fmt.fmt.pix_mp;
 	struct v4l2_window &win = fmt.fmt.win;
@@ -420,7 +422,7 @@ static int testFormatsType(struct node *node, int ret,  unsigned type, struct v4
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE:
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT:
 		fail_on_test(!pix.width || !pix.height);
-		if (set.find(pix.pixelformat) == set.end())
+		if (map.find(pix.pixelformat) == map.end())
 			return fail("unknown pixelformat %08x for buftype %d\n",
 					pix.pixelformat, type);
 		fail_on_test(pix.bytesperline && pix.bytesperline < pix.width);
@@ -435,9 +437,9 @@ static int testFormatsType(struct node *node, int ret,  unsigned type, struct v4
 	case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
 		fail_on_test(!pix_mp.width || !pix_mp.height);
-		set_splane = &node->buftype_pixfmts[type - 8];
-		if (set.find(pix_mp.pixelformat) == set.end() &&
-		    set_splane->find(pix_mp.pixelformat) == set_splane->end())
+		map_splane = &node->buftype_pixfmts[type - 8];
+		if (map.find(pix_mp.pixelformat) == map.end() &&
+		    map_splane->find(pix_mp.pixelformat) == map_splane->end())
 			return fail("unknown pixelformat %08x for buftype %d\n",
 					pix_mp.pixelformat, type);
 		if (!node->is_m2m)
@@ -529,7 +531,8 @@ static int testFormatsType(struct node *node, int ret,  unsigned type, struct v4
 		fail_on_test(win.global_alpha && !(node->fbuf_caps & V4L2_FBUF_CAP_GLOBAL_ALPHA));
 		break;
 	case V4L2_BUF_TYPE_SDR_CAPTURE:
-		if (set.find(sdr.pixelformat) == set.end())
+	case V4L2_BUF_TYPE_SDR_OUTPUT:
+		if (map.find(sdr.pixelformat) == map.end())
 			return fail("unknown pixelformat %08x for buftype %d\n",
 					pix.pixelformat, type);
 		fail_on_test(sdr.buffersize == 0);
@@ -549,7 +552,7 @@ int testGetFormats(struct node *node)
 	int type;
 	int ret;
 
-	for (type = 0; type <= V4L2_BUF_TYPE_SDR_CAPTURE; type++) {
+	for (type = 0; type <= V4L2_BUF_TYPE_LAST; type++) {
 		createInvalidFmt(fmt, clip, type);
 		ret = doioctl(node, VIDIOC_G_FMT, &fmt);
 		ret = testFormatsType(node, ret, type, fmt);
@@ -567,6 +570,7 @@ int testGetFormats(struct node *node)
 		case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
 		case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
 		case V4L2_BUF_TYPE_SDR_CAPTURE:
+		case V4L2_BUF_TYPE_SDR_OUTPUT:
 			if (ret && (node->g_caps() & buftype2cap[type]))
 				return fail("%s cap set, but no %s formats defined\n",
 					buftype2s(type).c_str(), buftype2s(type).c_str());
@@ -620,6 +624,7 @@ static bool matchFormats(const struct v4l2_format &f1, const struct v4l2_format
 	case V4L2_BUF_TYPE_VIDEO_OUTPUT_MPLANE:
 		return !memcmp(&f1.fmt.pix_mp, &f2.fmt.pix_mp, sizeof(f1.fmt.pix_mp));
 	case V4L2_BUF_TYPE_SDR_CAPTURE:
+	case V4L2_BUF_TYPE_SDR_OUTPUT:
 		return !memcmp(&f1.fmt.sdr, &f2.fmt.sdr, sizeof(f1.fmt.sdr));
 
 	}
@@ -634,7 +639,7 @@ int testTryFormats(struct node *node)
 	int type;
 	int ret;
 	
-	for (type = 0; type <= V4L2_BUF_TYPE_SDR_CAPTURE; type++) {
+	for (type = 0; type <= V4L2_BUF_TYPE_LAST; type++) {
 		if (!(node->valid_buftypes & (1 << type)))
 			continue;
 
@@ -663,7 +668,7 @@ int testTryFormats(struct node *node)
 					buftype2s(type).c_str());
 	}
 
-	for (type = 0; type <= V4L2_BUF_TYPE_SDR_CAPTURE; type++) {
+	for (type = 0; type <= V4L2_BUF_TYPE_LAST; type++) {
 		if (!(node->valid_buftypes & (1 << type)))
 			continue;
 
@@ -693,6 +698,7 @@ int testTryFormats(struct node *node)
 				pixelformat = fmt.fmt.pix.pixelformat;
 				break;
 			case V4L2_BUF_TYPE_SDR_CAPTURE:
+			case V4L2_BUF_TYPE_SDR_OUTPUT:
 				pixelformat = fmt.fmt.sdr.pixelformat;
 				break;
 			case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
@@ -793,7 +799,8 @@ static int testGlobalFormat(struct node *node, int type)
 	if (!node->g_direct() || (pixfmt1 == pixfmt2 && w1 == w2 && h1 == h2))
 		return 0;
 
-	if (type == V4L2_BUF_TYPE_SDR_CAPTURE) {
+	if (type == V4L2_BUF_TYPE_SDR_CAPTURE ||
+	    type == V4L2_BUF_TYPE_SDR_OUTPUT) {
 		sdr1->pixelformat = pixfmt1;
 		sdr2->pixelformat = pixfmt2;
 	} else if (type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE ||
@@ -820,7 +827,8 @@ static int testGlobalFormat(struct node *node, int type)
 		warn("Could not set fmt2\n");
 		return 0;
 	}
-	if (type == V4L2_BUF_TYPE_SDR_CAPTURE) {
+	if (type == V4L2_BUF_TYPE_SDR_CAPTURE ||
+	    type == V4L2_BUF_TYPE_SDR_OUTPUT) {
 		if (sdr1->pixelformat == sdr2->pixelformat) {
 			// This compliance test only succeeds if the two formats
 			// are really different after S_FMT
@@ -846,7 +854,8 @@ static int testGlobalFormat(struct node *node, int type)
 		}
 	}
 	doioctl(node, VIDIOC_G_FMT, &fmt1);
-	if (type == V4L2_BUF_TYPE_SDR_CAPTURE) {
+	if (type == V4L2_BUF_TYPE_SDR_CAPTURE ||
+	    type == V4L2_BUF_TYPE_SDR_OUTPUT) {
 		pixfmt1 = sdr1->pixelformat;
 		pixfmt2 = sdr2->pixelformat;
 	} else if (type == V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE ||
@@ -876,11 +885,11 @@ int testSetFormats(struct node *node)
 {
 	struct v4l2_clip clip, clip_set;
 	struct v4l2_format fmt, fmt_set;
-	struct v4l2_format initial_fmts[V4L2_BUF_TYPE_SDR_CAPTURE + 1];
+	struct v4l2_format initial_fmts[V4L2_BUF_TYPE_LAST + 1];
 	int type;
 	int ret;
 	
-	for (type = 0; type <= V4L2_BUF_TYPE_SDR_CAPTURE; type++) {
+	for (type = 0; type <= V4L2_BUF_TYPE_LAST; type++) {
 		if (!(node->valid_buftypes & (1 << type)))
 			continue;
 
@@ -900,6 +909,7 @@ int testSetFormats(struct node *node)
 
 			switch (type) {
 			case V4L2_BUF_TYPE_SDR_CAPTURE:
+			case V4L2_BUF_TYPE_SDR_OUTPUT:
 				pixelformat = fmt_set.fmt.sdr.pixelformat;
 				break;
 			case V4L2_BUF_TYPE_VIDEO_CAPTURE:
@@ -966,9 +976,10 @@ int testSetFormats(struct node *node)
 	if (node->is_m2m)
 		return 0;
 
-	for (type = 0; type <= V4L2_BUF_TYPE_SDR_CAPTURE; type++) {
+	for (type = 0; type <= V4L2_BUF_TYPE_LAST; type++) {
 		switch (type) {
 		case V4L2_BUF_TYPE_SDR_CAPTURE:
+		case V4L2_BUF_TYPE_SDR_OUTPUT:
 		case V4L2_BUF_TYPE_VIDEO_CAPTURE:
 		case V4L2_BUF_TYPE_VIDEO_OUTPUT:
 		case V4L2_BUF_TYPE_VIDEO_CAPTURE_MPLANE:
@@ -987,7 +998,7 @@ int testSetFormats(struct node *node)
 	}
 
 	/* Restore initial format */
-	for (type = 0; type <= V4L2_BUF_TYPE_SDR_CAPTURE; type++) {
+	for (type = 0; type <= V4L2_BUF_TYPE_LAST; type++) {
 		if (!(node->valid_buftypes & (1 << type)))
 			continue;
 
@@ -1122,7 +1133,7 @@ int testParm(struct node *node)
 	int type;
 	int ret;
 
-	for (type = 0; type <= V4L2_BUF_TYPE_SDR_CAPTURE; type++) {
+	for (type = 0; type <= V4L2_BUF_TYPE_LAST; type++) {
 		ret = testParmType(node, type);
 
 		if (ret && ret != ENOTTY)
