@@ -40,9 +40,9 @@ void vidout_usage(void)
 	       "                       alternate, interlaced_tb, interlaced_bt\n"
 	       "                     <c> can be one of the following colorspaces:\n"
 	       "                       smpte170m, smpte240m, rec709, 470m, 470bg, jpeg, srgb,\n"
-	       "                       adobergb, bt2020\n"
+	       "                       adobergb, bt2020, dcip3\n"
 	       "                     <xf> can be one of the following transfer functions:\n"
-	       "                       default, 709, srgb, adobergb, smpte240m, none\n"
+	       "                       default, 709, srgb, adobergb, smpte240m, smpte2084, dcip3, none\n"
 	       "                     <y> can be one of the following Y'CbCr encodings:\n"
 	       "                       default, 601, 709, xv601, xv709, sycc, bt2020, bt2020c, smpte240m\n"
 	       "                     <q> can be one of the following quantization methods:\n"
